# coding: utf-8

import requests
import urllib3

urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)


class LMSClient(object):
    def __init__(self):
        self.session = requests.Session()

    def login(self, id, pw):
        url = 'https://lms.pknu.ac.kr/ilos/lo/login.acl'
        headers = {
            'Referer': 'http://lms.pknu.ac.kr/ilos/main/member/login_form.acl',
        }
        data = {
            'returnURL': '',
            'challenge': '',
            'response': '',
            'usr_id': id,
            'usr_pwd': pw,
        }
        r = self.session.post(url, headers=headers, data=data, verify=False)

        return u'로그인 정보가 일치하지 않습니다' not in r.text

    def logout(self):
        url = 'http://lms.pknu.ac.kr/ilos/lo/logout.acl'
        headers = {
            'Referer': 'http://lms.pknu.ac.kr/ilos/main/main_form.acl',
        }
        r = self.session.get(url, headers=headers)

    def send_note(self, to, title, content):
        url = 'http://lms.pknu.ac.kr/ilos/message/insert_pop.acl'
        headers = {
            'Referer': 'http://lms.pknu.ac.kr/ilos/message/insert_pop_form.acl',
        }
        data = {
            'TITLE': title,
            'RECV_IDs': to + '^',
            'CONTENT': content,
            'encoding': 'utf-8',
        }
        r = self.session.post(
            url, headers=headers, data=data, allow_redirects=False)

        try:
            body = r.json()
        except ValueError:
            return False

        return not body['isError']



import os
from setuptools import setup


def get_content(path):
    path = os.path.join(os.path.dirname(os.path.abspath(__file__)), path)
    with open(path) as f:
        return f.read()


setup(
    name='pknulms',
    version='1.0.0',
    url='https://github.com/hallazzang/pknulms-py',
    license='MIT',
    author='Hanjun Kim',
    author_email='hallazzang@gmail.com',
    description='Pukyong National University Smart-LMS Python client',
    long_description=get_content('README.md'),
    py_modules=['pknulms'],
    install_requires=[
        'requests',
    ],
    zip_safe=False,
    platforms='any',
    classifiers=[
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)
